# coding=utf-8

# Unsplash
# Copyright 2018 Yakup Adaklı
# See LICENSE for details.

"""A library that provides a Python wrapper to the RestCountries API"""

__version__ = "1.0.0b1"
__author__ = "Yakup Adaklı"
__license__ = "MIT"
